.. _api:

=============
API Reference
=============

All the available functions and APIs are listed in current page.
You are able to investigate A to Z in PrismStudio!

.. toctree::
    :maxdepth: 3

    general
    search
    data
    uandp
    query
    datafiles
    preference
    securitymaster
    functions
    tasks
    jobs
    prismcomponent
    tcmodel
